pub struct HeartbeatHandlerGroupBuilder {
region_failure_handler: Option<RegionFailureHandler>,
region_lease_handler: Option<RegionLeaseHandler>,
flush_stats_factor: Option<usize>,
flow_state_handler: Option<FlowStateHandler>,
persist_stats_handler: Option<PersistStatsHandler>,
plugins: Option<Plugins>,
pushers: Pushers,
handlers: Vec<NameCachedHandler>,
}Expand description
The builder to build the group of heartbeat handlers.
Fields
region_failure_handler: Option<RegionFailureHandler>The handler to handle region failure.
region_lease_handler: Option<RegionLeaseHandler>The handler to handle region lease.
flush_stats_factor: Option<usize>The factor that determines how often statistics should be flushed, based on the number of received heartbeats. When the number of heartbeats reaches this factor, a flush operation is triggered.
flow_state_handler: Option<FlowStateHandler>A simple handler for flow internal state report
persist_stats_handler: Option<PersistStatsHandler>The handler to persist stats.
plugins: Option<Plugins>The plugins.
pushers: PushersThe heartbeat response pushers.
handlers: Vec<NameCachedHandler>The group of heartbeat handlers.
Implementations
Sourceimpl HeartbeatHandlerGroupBuilder
impl HeartbeatHandlerGroupBuilder
pub fn new(pushers: Pushers) -> Self
pub fn with_flow_state_handler(self, handler: Option<FlowStateHandler>) -> Self
pub fn with_region_lease_handler( self, handler: Option<RegionLeaseHandler>, ) -> Self
Sourcepub fn with_region_failure_handler(
self,
handler: Option<RegionFailureHandler>,
) -> Self
pub fn with_region_failure_handler( self, handler: Option<RegionFailureHandler>, ) -> Self
Sets the RegionFailureHandler.
Sourcepub fn with_flush_stats_factor(self, flush_stats_factor: Option<usize>) -> Self
pub fn with_flush_stats_factor(self, flush_stats_factor: Option<usize>) -> Self
Sets the flush stats factor.
pub fn with_persist_stats_handler( self, handler: Option<PersistStatsHandler>, ) -> Self
Sourcepub fn with_plugins(self, plugins: Option<Plugins>) -> Self
pub fn with_plugins(self, plugins: Option<Plugins>) -> Self
Sets the [Plugins].
Sourcepub fn add_default_handlers(self) -> Self
pub fn add_default_handlers(self) -> Self
Adds the default handlers.
Sourcepub fn build(self) -> Result<HeartbeatHandlerGroup>
pub fn build(self) -> Result<HeartbeatHandlerGroup>
Builds the group of heartbeat handlers.
Applies the customizer if it exists.
fn add_handler_after_inner( &mut self, target: &str, handler: NameCachedHandler, ) -> Result<()>
Sourcepub fn add_handler_after(
&mut self,
target: &'static str,
handler: impl HeartbeatHandler + 'static,
) -> Result<()>
pub fn add_handler_after( &mut self, target: &'static str, handler: impl HeartbeatHandler + 'static, ) -> Result<()>
Adds the handler after the specified handler.
fn add_handler_before_inner( &mut self, target: &str, handler: NameCachedHandler, ) -> Result<()>
Sourcepub fn add_handler_before(
&mut self,
target: &'static str,
handler: impl HeartbeatHandler + 'static,
) -> Result<()>
pub fn add_handler_before( &mut self, target: &'static str, handler: impl HeartbeatHandler + 'static, ) -> Result<()>
Adds the handler before the specified handler.
fn replace_handler_inner( &mut self, target: &str, handler: NameCachedHandler, ) -> Result<()>
Sourcepub fn replace_handler(
&mut self,
target: &'static str,
handler: impl HeartbeatHandler + 'static,
) -> Result<()>
pub fn replace_handler( &mut self, target: &'static str, handler: impl HeartbeatHandler + 'static, ) -> Result<()>
Replaces the handler with the specified name.
fn add_handler_last_inner(&mut self, handler: NameCachedHandler)
fn add_handler_last(&mut self, handler: impl HeartbeatHandler + 'static)